/* ************************************************ OVERRIDDEN VARIABLES ************************************************ */

:root {
    --bs-primary: var(--app-primary-color);
    --bs-primary-rgb: var(--app-primary-color-rgb);
    --bs-secondary: var(--app-secondary-color);
    --bs-secondary-rgb: var(--app-secondary-color-rgb);
    --bs-link-color-rgb: var(--bs-primary-rgb);
    --bs-link-hover-color-rgb: var(--bs-primary-rgb);
}

.btn {
    --bs-btn-box-shadow: none;
}

.btn-primary {
    --bs-btn-bg: var(--bs-primary);
    --bs-btn-border-color: var(--bs-primary);
    --bs-btn-hover-color: var(--bs-primary);
    --bs-btn-hover-bg: var(--bs-white);
    --bs-btn-hover-border-color: var(--bs-primary);
    --bs-btn-active-color: var(--bs-primary);
    --bs-btn-active-bg: var(--bs-white);
    --bs-btn-active-border-color: var(--bs-primary);
}

.btn-outline-primary {
    --bs-btn-color: var(--bs-primary);
    --bs-btn-border-color: var(--bs-primary);
    --bs-btn-hover-bg: var(--bs-primary);
    --bs-btn-hover-border-color: var(--bs-primary);
    --bs-btn-active-bg: var(--bs-primary);
    --bs-btn-active-border-color: var(--bs-primary);
}

.btn-secondary {
    --bs-btn-hover-color: var(--bs-secondary);
    --bs-btn-hover-bg: var(--bs-white);
    --bs-btn-active-color: var(--bs-secondary);
    --bs-btn-active-bg: var(--bs-white);
}

.table {
    --bs-table-border-color: var(--bs-primary);
}

.card-primary {
    --lte-card-variant-bg: var(--bs-primary);
}

/* ************************************************ HEADER ************************************************ */

.navbar-nav > .user-menu > .dropdown-menu > .user-body {
    padding: 10px;
}

@media (min-width: 576px) {
    .navbar-nav > .user-menu > .dropdown-menu > .user-body a {
        color: var(--bs-white) !important;
        background-color: var(--bs-btn-bg) !important;
    }
    .navbar-nav > .user-menu > .dropdown-menu > .user-body a:hover {
        color: var(--bs-btn-hover-color) !important;
        background-color: var(--bs-white) !important;
    }
}

.navbar-nav > .user-menu > .dropdown-menu > .user-body a:not(:last-child) {
    margin-bottom: 10px;
}

/* ************************************************ SIDEBAR ************************************************ */

.sidebar-brand {
    padding-block: 12px;
}

.sidebar-brand .brand-link .brand-image {
    max-height: 32px;
}

/* ************************************************ ICONS ************************************************ */

.bi {
    vertical-align: middle;
}

/* ************************************************ TABLES ************************************************ */

.table {
    border: 1px solid var(--bs-table-border-color);
    border-radius: 6px;
    border-collapse: separate;
    border-spacing: 0;
    overflow: hidden;
}

.table thead th {
    color: var(--bs-white);
    background-color: var(--bs-primary);
    white-space: pre;
}

.table tbody tr:last-child {
    border-color: transparent;
}
