<a href="{% url list_url_name %}" class="btn btn-secondary me-2">
    <i class="bi bi-arrow-counterclockwise me-2"></i>Volver
</a>

<button type="submit" class="btn btn-primary">
    <i class="bi bi-cloud-plus-fill me-2"></i>Crear
</button>
