{% load static %}

<!DOCTYPE html>
<html lang="es">
    <head>
        <meta charset="utf-8">

        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        <title>
            {% block ecom_statics_browser_title %}
                {% block ecom_statics_left_browser_title %}Inicio{% endblock %}
                {% block ecom_statics_right_browser_title %} | Ecom Statics{% endblock %}
            {% endblock %}
        </title>

        <link rel="shortcut icon" href="{% block ecom_statics_favicon %}{% static 'ecom_statics/images/favicons/ecom.ico' %}{% endblock %}">

        {% block ecom_statics_css_base %}
            <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/@fontsource/source-sans-3@5.0.12/index.css" integrity="sha256-tXJfXfp6Ewt1ilPzLDtQnJV4hclT9XuaZUKyUvmyr+Q=" crossorigin="anonymous" media="print" onload="this.media='all'">

            <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/overlayscrollbars@2.11.0/styles/overlayscrollbars.min.css" crossorigin="anonymous">

            <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.13.1/font/bootstrap-icons.min.css" crossorigin="anonymous">

            <link rel="stylesheet" href="{% static 'ecom_statics/vendors/select2/css/select2.min.css' %}">

            <link rel="stylesheet" href="{% static 'ecom_statics/modules/select2/css/custom_select2.css' %}">

            <link rel="stylesheet" href="{% static 'ecom_statics/css/adminlte.css' %}">
        {% endblock %}

        {% block ecom_statics_css_variables %}
            <link rel="stylesheet" href="{% static 'ecom_statics/css/variables.css' %}">
        {% endblock %}

        {% block ecom_statics_css_custom %}
            <link rel="stylesheet" href="{% static 'ecom_statics/css/custom_adminlte.css' %}">
        {% endblock %}

        {% block ecom_statics_css_extras %}{% endblock %}
    </head>

    <body class="sidebar-expand-lg sidebar-open bg-body-tertiary">
        <div class="app-wrapper">
            {% block ecom_statics_header %}
                {% include 'ecom_statics/base/header.html' %}
            {% endblock %}

            {% block ecom_statics_sidebar %}
                {% include 'ecom_statics/base/sidebar.html' %}
            {% endblock %}

            {% block ecom_statics_main %}
                <main class="app-main">
                    {% block ecom_statics_main_header %}
                        <div class="app-content-header">
                            <div class="container-fluid">
                                <div class="row">
                                    <div class="col-sm-6">
                                        <h3 class="mb-0">
                                            {% block ecom_statics_page_icon %}<i class="bi bi-house-fill me-2"></i>{% endblock %}
                                            {% block ecom_statics_page_title %}Ecom Statics{% endblock %}
                                        </h3>
                                    </div>

                                    {% block ecom_statics_breadcrumb %}
                                        <div class="col-sm-6">
                                            {% include 'ecom_statics/includes/breadcrumb.html' %}
                                        </div>
                                    {% endblock %}
                                </div>
                            </div>
                        </div>
                    {% endblock %}

                    {% block ecom_statics_main_content_base %}
                        <div class="app-content">
                            <div class="container-fluid">
                                <div class="row">
                                    {% block ecom_statics_main_content %}
                                        <div class="col-12">
                                            <div class="card">
                                                {% block ecom_statics_card_header %}
                                                    <div class="card-header">
                                                        <h3 class="card-title">{% block ecom_statics_card_title %}Título{% endblock %}</h3>

                                                        {% block ecom_statics_card_tools %}
                                                            <div class="card-tools">
                                                                <button type="button" class="btn btn-tool" data-lte-toggle="card-collapse" title="Collapse">
                                                                    <i data-lte-icon="expand" class="bi bi-plus-lg"></i>
                                                                    <i data-lte-icon="collapse" class="bi bi-dash-lg"></i>
                                                                </button>
                                                            </div>
                                                        {% endblock %}
                                                    </div>
                                                {% endblock %}

                                                {% block ecom_statics_card_body %}
                                                    <div class="card-body">Información Relevante</div>
                                                {% endblock %}

                                                {% block ecom_statics_card_footer %}
                                                    <div class="card-footer">Información Adicional</div>
                                                {% endblock %}
                                            </div>
                                        </div>
                                    {% endblock %}
                                </div>
                            </div>
                        </div>
                    {% endblock %}
                </main>
            {% endblock %}

            {% block ecom_statics_footer %}
                {% include 'ecom_statics/base/footer.html' %}
            {% endblock %}
        </div>

        {% block ecom_statics_js_base %}
            <script src="https://cdn.jsdelivr.net/npm/overlayscrollbars@2.11.0/browser/overlayscrollbars.browser.es6.min.js" crossorigin="anonymous"></script>

            <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js" crossorigin="anonymous"></script>

            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.7/dist/js/bootstrap.min.js" crossorigin="anonymous"></script>

            <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js" crossorigin="anonymous"></script>
            
            <script src="{% static 'ecom_statics/vendors/select2/js/select2.min.js' %}"></script>

            <script src="{% static 'ecom_statics/modules/select2/js/inicializar_select2.js' %}"></script>

            <script src="{% static 'ecom_statics/js/adminlte.js' %}"></script>
        {% endblock %}

        {% block ecom_statics_js_extras %}{% endblock %}
    </body>
</html>
